searchData={"items":[{"type":"module","title":"Livebook","doc":"This module provides a public Elixir API for integrating with Livebook.","ref":"Livebook.html"},{"type":"module","title":"Configuration - Livebook","doc":"See `config_runtime/0` for bootstrapping the default runtime\nconfiguration. There are several public configuration entries that\nyou can customize.\n\n#","ref":"Livebook.html#module-configuration"},{"type":"module","title":"Custom plugs - Livebook","doc":"You can list a number of plugs to call directly before the Livebook\nrouter\n\n    config :livebook, :plugs, [{CustomPlug, []}]\n\n#","ref":"Livebook.html#module-custom-plugs"},{"type":"module","title":"Embedded runtime dependencies - Livebook","doc":"In case you use the Embedded runtime and support installing\ndependencies with `Mix.install/2`, you can make those discoverable\nin the package search, by configuring a loader function:\n\n    config :livebook, Livebook.Runtime.Embedded,\n      load_packages: {Loader, :packages, []}\n\nThe function should return a list of entries like this:\n\n    [\n      %{\n        dependency: %{dep: {:kino, \"~> 0.6.1\"}, config: []},\n        description: \"Interactive widgets for Livebook\",\n        name: \"kino\",\n        url: \"https://hex.pm/packages/kino\",\n        version: \"0.6.1\"\n      }\n    ]\n\n#","ref":"Livebook.html#module-embedded-runtime-dependencies"},{"type":"module","title":"Custom learn notebooks - Livebook","doc":"**Note that this is compile time configuration.**\n\nA list of additional notebooks to include in the Learn section.\n\nNote that the notebooks are loaded and embedded in a compiled module,\nso the paths are accessed at compile time only.\n\n    config :livebook, :learn_notebooks, [\n      %{\n        # Required notebook path\n        path: \"/path/to/notebook.livemd\",\n        # Optional notebook identifier for URLs, as in /learn/notebooks/{slug}\n        # By default the slug is inferred from file name, so there is no need to set it\n        slug: \"my-notebook\"\n        # Optional list of images\n        image_paths: [\n          # This image can be sourced as images/myimage.jpg in the notebook\n          \"/path/to/myimage.jpg\"\n        ],\n        # Optional details for the notebook card. If omitted, the notebook\n        # is hidden in the UI, but still accessible under /learn/notebooks/{slug}\n        details: %{\n          cover_path: \"/path/to/logo.png\",\n          description: \"My custom notebook that showcases some amazing stuff.\"\n        }\n      },\n      %{\n        path: \"/path/to/other_notebook.livemd\"\n      }\n    ]","ref":"Livebook.html#module-custom-learn-notebooks"},{"type":"function","title":"Livebook.config_runtime/0","doc":"Executes Livebook's `config/runtime.exs`.\n\nIf you use Livebook as a dependency, you can add the following\nto your `config/runtime.exs` to trigger Livebook's `config/runtime.exs`\nconfiguration:\n\n    Livebook.config_runtime()","ref":"Livebook.html#config_runtime/0"},{"type":"function","title":"Livebook.live_markdown_to_elixir/1","doc":"Parses the given Live Markdown document and converts it to Elixir\nsource code.","ref":"Livebook.html#live_markdown_to_elixir/1"},{"type":"function","title":"Limitations - Livebook.live_markdown_to_elixir/1","doc":"Note that the resulting script may not compile in some cases, for\nexample if you define a macro in one cell and import it in another\ncell, it works fine in Livebook, because each cell is compiled\nseparately. However, when running the script it gets compiled as a\nwhole and consequently doing so doesn't work.\n\nAdditionally, branching sections are commented out.","ref":"Livebook.html#live_markdown_to_elixir/1-limitations"},{"type":"extras","title":"Welcome to Livebook","doc":"# Livebook\n\n[![Website](https://img.shields.io/badge/-Website-%23ff87a7)](https://livebook.dev/)\n[![Latest Version](https://img.shields.io/hexpm/v/livebook?color=b5a3be&label=Latest+version)](https://hexdocs.pm/livebook)\n\nLivebook is a web application for writing interactive and collaborative code notebooks. It features:\n\n  * Code notebooks with Markdown support and Code cells where Elixir code is evaluated on demand.\n\n  * Rich code editor through [Monaco](https://microsoft.github.io/monaco-editor/): with support for autocompletion, inline documentation, code formatting, etc.\n\n  * Interactive results via [Kino](https://github.com/elixir-nx/kino): display [Vega-Lite charts](https://vega.github.io/vega-lite/), tables, maps, and more.\n\n  * Automation: use Smart cells to perform high-level tasks and write notebooks faster than ever. Query databases, plot charts, build maps, and more directly from Livebook's UI.\n\n  * Reproducible: Livebook ensures your code runs in a predictable order, all the way down to package management. It also tracks your notebook state, annotating which parts are stale.\n\n  * Collaboration: multiple users can work on the same notebook at once, no additional setup required.\n\n  * Decentralized: Livebook is open-source and you can run it anywhere. The [\"Run in Livebook\" badge](https://livebook.dev/badge) makes it easy to import any Livebook into your own Livebook.\n\n  * Versionable: notebooks are stored in the `.livemd` format, which is a subset of Markdown with support for diagrams via [Mermaid](https://mermaid-js.github.io/mermaid) and for mathematical formulas via [KaTex](https://katex.org/). `.livemd` files can be shared and play well with version control.\n\n  * Custom runtimes: when executing Elixir code, you can either start a fresh Elixir instance, connect to an existing node, or run it inside an existing Elixir project, with access to all of its modules and dependencies. This means Livebook can be a great tool to introspect and document existing projects too.","ref":"readme.html"},{"type":"extras","title":"Getting started - Welcome to Livebook","doc":"Head out to [the Install section](https://livebook.dev/#install) of Livebook's website to get started. Once Livebook is up and running on your machine, **visit the \"Learn\" section** with introductory guides and documentation on several Livebook features. Here is a sneak peak of the \"Welcome to Livebook\" guide:\n\n![Screenshot](https://github.com/livebook-dev/livebook/raw/main/.github/imgs/welcome.png)\n\nFor screencasts and news, check out [news.livebook.dev](https://news.livebook.dev/).","ref":"readme.html#getting-started"},{"type":"extras","title":"Installation - Welcome to Livebook","doc":"We provide several methods for running Livebook,\npick the one that best fits your use case.\n\n#","ref":"readme.html#installation"},{"type":"extras","title":"Desktop app - Welcome to Livebook","doc":"* [Download the installer for Mac and Windows from our homepage](https://livebook.dev/#install)\n\n  * Latest stable builds: [Mac (Universal)](https://livebook.dev/releases/latest/LivebookInstall-latest-macos-universal.dmg),\n    [Windows](https://livebook.dev/releases/latest/LivebookInstall-latest-windows-x86_64.exe)\n\n  * Nightly builds: [Mac (Universal)](https://livebook.dev/releases/nightly/LivebookInstall-nightly-macos-universal.dmg),\n    [Windows](https://livebook.dev/releases/nightly/LivebookInstall-nightly-windows-x86_64.exe)\n\n  * Builds for particular Livebook version are available on our\n    [GitHub releases](https://github.com/livebook-dev/livebook/releases).\n\n#","ref":"readme.html#desktop-app"},{"type":"extras","title":"Docker - Welcome to Livebook","doc":"Running Livebook using Docker is another great option to run Livebook\nin case you don't have Elixir installed.\n\n```shell\n# Running with the default configuration\ndocker run -p 8080:8080 -p 8081:8081 --pull always ghcr.io/livebook-dev/livebook\n\n# In order to access and save notebooks directly to your machine\n# you can mount a local directory into the container.\n# Make sure to specify the user with \"-u $(id -u):$(id -g)\"\n# so that the created files have proper permissions\ndocker run -p 8080:8080 -p 8081:8081 --pull always -u $(id -u):$(id -g) -v $(pwd):/data ghcr.io/livebook-dev/livebook\n\n# You can configure Livebook using environment variables,\n# for all options see the dedicated \"Environment variables\" section below\ndocker run -p 8080:8080 -p 8081:8081 --pull always -e LIVEBOOK_PASSWORD=\"securesecret\" ghcr.io/livebook-dev/livebook\n\n# Or if you need to run on different ports:\ndocker run -p 8090:8090 -p 8091:8091 --pull always -e LIVEBOOK_PORT=8090 -e LIVEBOOK_IFRAME_PORT=8091 ghcr.io/livebook-dev/livebook\n```\n\nTo deploy Livebook on your cloud platform, see our [Docker Deployment](docs/deployment/docker.md) guide.\n\nFor CUDA support, [see images with the \"cuda\" tag](https://github.com/livebook-dev/livebook/pkgs/container/livebook).\n\nTo try out features from the main branch you can alternatively\nuse the `ghcr.io/livebook-dev/livebook:edge` image.\nSee [Livebook images](https://github.com/livebook-dev/livebook/pkgs/container/livebook).\n\n#","ref":"readme.html#docker"},{"type":"extras","title":"Embedded devices - Welcome to Livebook","doc":"If you want to run Livebook on embedded devices, such as Raspberry Pi, BeagleBone, etc.,\ncheck out [the Livebook firmware](https://github.com/nerves-livebook/nerves_livebook) built\nwith [Nerves](https://www.nerves-project.org/).\n\n#","ref":"readme.html#embedded-devices"},{"type":"extras","title":"Direct installation with Elixir - Welcome to Livebook","doc":"You can run Livebook on your own machine using just Elixir. You will need\n[Elixir v1.15.2](https://elixir-lang.org/install.html) or later.\nLivebook also requires the following Erlang applications: `inets`,\n`os_mon`, `runtime_tools`, `ssl` and `xmerl`. Those applications come\nwith most Erlang distributions but certain package managers may split\nthem apart. For example, on Ubuntu, these Erlang applications can\nbe installed as follows:\n\n```shell\nsudo apt install erlang-inets erlang-os-mon erlang-runtime-tools erlang-ssl erlang-xmerl erlang-dev erlang-parsetools\n```\n\n**Note:** The [`livebook` package](https://hex.pm/packages/livebook)\nis meant to be used as a CLI tool. Livebook is not officially\nsupported as a Mix/Hex dependency.\n\n##","ref":"readme.html#direct-installation-with-elixir"},{"type":"extras","title":"Escript - Welcome to Livebook","doc":"Running Livebook using Escript makes for a very convenient option\nfor local usage and provides easy configuration via CLI options.\n\n```shell\nmix do local.rebar --force, local.hex --force\nmix escript.install hex livebook\n\n# Start the Livebook server\nlivebook server\n\n# See all the configuration options\nlivebook server --help\n```\n\nAfter you install the escript, make sure you add the directory where\nElixir keeps escripts to your [$PATH](https://en.wikipedia.org/wiki/PATH_(variable)).\nIf you installed Elixir with `asdf`, you'll need to run `asdf reshim elixir`\nonce the escript is built.\n\nTo try out features from the main branch you can alternatively\ninstall the escript directly from GitHub like this:\n\n```shell\nmix escript.install github livebook-dev/livebook\n```\n\n##","ref":"readme.html#escript"},{"type":"extras","title":"From source - Welcome to Livebook","doc":"You can run latest Livebook directly from source.\n\n```shell\ngit clone https://github.com/livebook-dev/livebook.git\ncd livebook\nmix deps.get --only prod\n\n# Run the Livebook server\nMIX_ENV=prod mix phx.server\n```","ref":"readme.html#from-source"},{"type":"extras","title":"Security considerations - Welcome to Livebook","doc":"Livebook is built to document and execute code. Anyone with access to a Livebook instance\nwill be able to access any file and execute any code in the machine Livebook is running.\n\nFor this reason, Livebook only binds to the 127.0.0.1, allowing access to happen only within\nthe current machine. When running Livebook in the production environment - the recommended\nenvironment - we also generate a token on initialization and we only allow access to the\nLivebook if said token is supplied as part of the URL.","ref":"readme.html#security-considerations"},{"type":"extras","title":"Environment variables - Welcome to Livebook","doc":"The following environment variables can be used to configure Livebook on boot:\n\n  * `LIVEBOOK_ALLOW_URI_SCHEMES` - sets additional allowed hyperlink schemes to the\n    Markdown content. Livebook sanitizes links in Markdown, allowing only a few\n    standard schemes by default (such as http and https). Set it to a comma-separated\n    list of schemes.\n\n  * `LIVEBOOK_APP_SERVICE_NAME` - sets the application name used by the cloud\n    provider to aid debugging.\n\n  * `LIVEBOOK_APP_SERVICE_URL` - sets the application url to manage this\n    Livebook instance within the cloud provider platform.\n\n  * `LIVEBOOK_APPS_PATH` - the directory with app notebooks. When set, the apps\n    are deployed on Livebook startup with the persisted settings. Password-protected\n    notebooks will receive a random password, unless `LIVEBOOK_APPS_PATH_PASSWORD`\n    is set. When deploying using Livebook's Docker image, consider using\n    `LIVEBOOK_APPS_PATH_WARMUP`.\n\n  * `LIVEBOOK_APPS_PATH_HUB_ID` - deploy only the notebooks in\n    `LIVEBOOK_APPS_PATH` that belong to the given Hub ID\n\n  * `LIVEBOOK_APPS_PATH_PASSWORD` - the password to use for all protected apps\n    deployed from `LIVEBOOK_APPS_PATH`.\n\n  * `LIVEBOOK_APPS_PATH_WARMUP` - sets the warmup mode for apps deployed from\n    `LIVEBOOK_APPS_PATH`. Must be either \"auto\" (apps are warmed up on Livebook\n    startup, right before app deployment) or \"manual\" (apps are warmed up when\n    building the Docker image; to do so add \"RUN /app/bin/warmup_apps\" to\n    your image). Defaults to \"auto\".\n\n  * `LIVEBOOK_AWS_CREDENTIALS` - enable Livebook to read AWS Credentials from\n    environment variables, AWS Credentials, EC2/ECS metadata when configuring\n    S3 buckets.\n\n  * `LIVEBOOK_BASE_URL_PATH` - sets the base url path the web application is\n    served on. Useful when deploying behind a reverse proxy.\n\n  * `LIVEBOOK_CACERTFILE` - path to a local file containing CA certificates.\n    Those certificates are used during for server authentication when Livebook\n    accesses files from external sources.\n\n  * `LIVEBOOK_CLUSTER` - configures clustering strategy when running multiple\n    instances of Livebook. See the \"Clustering\" section of our Docker Deployment\n    guide for more information: https://hexdocs.pm/livebook/docker.html\n\n  * `LIVEBOOK_COOKIE` - sets the cookie for running Livebook in a cluster.\n    Defaults to a random string that is generated on boot.\n\n  * `LIVEBOOK_DATA_PATH` - the directory to store Livebook's internal\n    configuration. Defaults to \"livebook\" under the default user data\n    directory.\n\n  * `LIVEBOOK_DEBUG` - enables verbose logging, when set to \"true\". Disabled\n    by default.\n\n  * `LIVEBOOK_DEFAULT_RUNTIME` - sets the runtime type that is used by default\n    when none is started explicitly for the given notebook. Must be either\n    \"standalone\" (Elixir standalone), \"attached:NODE:COOKIE\" (Attached node)\n    or \"embedded\" (Embedded). Defaults to \"standalone\".\n\n  * `LIVEBOOK_DISTRIBUTION` - sets the node distribution for running Livebook in a\n    cluster. Must be \"name\" (long names) or \"sname\" (short names). Note that this\n    sets RELEASE_DISTRIBUTION if present when creating a release. Defaults to \"sname\".\n\n  * `LIVEBOOK_FORCE_SSL_HOST` - sets a host to redirect to if the request is not over HTTPS.\n    Note it does not apply when accessing Livebook via localhost. Defaults to nil.\n\n  * `LIVEBOOK_HOME` - sets the home path for the Livebook instance. This is the\n    default path used on file selection screens and others. Defaults to the\n    user's operating system home.\n\n  * `LIVEBOOK_IDENTITY_PROVIDER` - controls whether Zero Trust Authentication\n    must be used as the identity provider. This is useful when deploying\n    Livebook inside a cloud platform, such as Cloudflare and Google.\n    Supported values are:\n\n      * \"cloudflare: \"\n      * \"google_iap: \"\n      * \"tailscale: \"\n      * \"teleport: \"\n      * \"custom:YourElixirModule\"\n\n    See our authentication docs for more information: https://hexdocs.pm/livebook/authentication.html\n\n  * `LIVEBOOK_IFRAME_PORT` - sets the port that Livebook serves iframes at.\n    This is relevant only when running Livebook without TLS. Defaults to 8081.\n\n  * `LIVEBOOK_IFRAME_URL` - sets the URL that Livebook loads iframes from.\n    By default iframes are loaded from local `LIVEBOOK_IFRAME_PORT` when accessing\n    Livebook over http:// and from https://livebookusercontent.com when accessing over https://.\n\n  * `LIVEBOOK_IP` - sets the ip address to start the web application on.\n    Must be a valid IPv4 or IPv6 address.\n\n  * `LIVEBOOK_NODE` - sets the node name for running Livebook in a cluster. Note that\n    this sets RELEASE_NODE if present when creating a release.\n\n  * `LIVEBOOK_PASSWORD` - sets a password that must be used to access Livebook.\n    Must be at least 12 characters. Defaults to token authentication.\n\n  * `LIVEBOOK_PORT` - sets the port Livebook runs on. If you want to run multiple\n    instances on the same domain with the same credentials but on different ports,\n    you also need to set `LIVEBOOK_SECRET_KEY_BASE`. Defaults to 8080. If set to 0,\n    a random port will be picked.\n\n  * `LIVEBOOK_SECRET_KEY_BASE` - sets a secret key that is used to sign and encrypt\n    the session and other payloads used by Livebook. Must be at least 64 characters\n    long and it can be generated by commands such as: `openssl rand -base64 48`.\n    Defaults to a random secret on every boot.\n\n  * `LIVEBOOK_SHUTDOWN_ENABLED` - controls if a shutdown button should be shown\n    in the homepage. Set it to \"true\" to enable it.\n\n  * `LIVEBOOK_TOKEN_ENABLED` - controls whether token authentication is enabled.\n    Enabled by default unless `LIVEBOOK_PASSWORD` is set. Set it to \"false\" to\n    disable it.\n\n  * `LIVEBOOK_UPDATE_INSTRUCTIONS_URL` - sets the URL to direct the user to for\n    updating Livebook when a new version becomes available.\n\n  * `LIVEBOOK_WITHIN_IFRAME` - controls if the application is running inside an\n    iframe. Set it to \"true\" to enable it. If you do enable it, then the application\n    must run with HTTPS.\n\n \n\nIf running Livebook via the command line, run `livebook server --help` to see\nall CLI-specific options.\n\n#","ref":"readme.html#environment-variables"},{"type":"extras","title":"Livebook Desktop - Welcome to Livebook","doc":"When running Livebook Desktop, Livebook will invoke on boot a file named\n`~/.livebookdesktop.sh` on macOS or `%USERPROFILE%\\.livebookdesktop.bat`\non Windows. This file can set environment variables used by Livebook,\nsuch as:\n\n  * [the `PATH` environment variable](https://en.wikipedia.org/wiki/PATH_(variable))\n\n  * set `LIVEBOOK_DISTRIBUTION=name` to enable notebooks to communicate\n    with nodes in other machines\n\n  * or to configure the Erlang VM, for instance, by setting\n    `ERL_AFLAGS=\"-proto_dist inet6_tcp\"` if you need Livebook to run over IPv6\n\nBe careful when modifying boot files, Livebook may be unable to start if\nconfigured incorrectly.","ref":"readme.html#livebook-desktop"},{"type":"extras","title":"Development - Welcome to Livebook","doc":"Livebook is primarily a Phoenix web application and can be setup as such:\n\n```shell\ngit clone https://github.com/livebook-dev/livebook.git\ncd livebook\nmix setup\n\n# Run the Livebook server\nmix phx.server\n\n# Run tests\nmix test\n```\n\nOnce you submit a pull request, [Uffizzi](https://www.uffizzi.com) will setup\na preview environment where anyone can try out your changes and give feedback.\n\n#","ref":"readme.html#development"},{"type":"extras","title":"Desktop app builds - Welcome to Livebook","doc":"For macOS, run:\n\n```shell\n# Test macOS app locally\n(cd rel/app/macos && ./run.sh)\n\n# Build macOS installer\n.github/scripts/app/build_macos.sh\n```\n\nFor Windows, run:\n\n```shell\n# Test Windows app locally\n(cd rel/app/windows && ./run.sh)\n\n# Build Windows installer\n.github/scripts/app/build_windows.sh\n```","ref":"readme.html#desktop-app-builds"},{"type":"extras","title":"Sponsors - Welcome to Livebook","doc":"Livebook development is sponsored by:","ref":"readme.html#sponsors"},{"type":"extras","title":"Supporters - Welcome to Livebook","doc":"Machine Learning and Neural Network models hosted by:","ref":"readme.html#supporters"},{"type":"extras","title":"License - Welcome to Livebook","doc":"Copyright (C) 2021 Dashbit\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"Authentication","doc":"# Authentication","ref":"authentication.html"},{"type":"extras","title":"Introduction - Authentication","doc":"Livebook's authentication covers all pages for creating, writing, and managing notebooks.\n\nLivebook's default authentication method is token authentication.  A token is automatically generated at startup and printed to the logs.\n\nYou may optionally enable password-based authentication by setting the environment variable `LIVEBOOK_PASSWORD` on startup or deployment. It must be at least 12 characters.\n\nTo disable authentication altogether, you may set the environment variable `LIVEBOOK_TOKEN_ENABLED` to `false`.","ref":"authentication.html#introduction"},{"type":"extras","title":"Securing deployed notebooks - Authentication","doc":"When you deploy a notebook as an application, the deployed application is not covered by Livebook's token/password authentication. In such cases, you have two options:\n\n  * You can set a password when deploying your notebook\n\n  * You can enable proxy authentication when deploying inside a cloud infrastructure.\n    See the \"Deployment\" section on the sidebar for more information","ref":"authentication.html#securing-deployed-notebooks"},{"type":"extras","title":"Intro to Livebook Teams","doc":"# Intro to Livebook Teams\n\n[Livebook Teams](https://livebook.dev/teams/?ref=docs) is a product that amplifies Livebook with features designed for teams and businesses.\n\nIt's currently in free beta. You can [join the beta waiting list here](https://livebook.dev/teams/?ref=docs) to get early access.","ref":"intro_to_teams.html"},{"type":"extras","title":"Current features in the beta - Intro to Livebook Teams","doc":"- [Shared secrets management](shared_secrets.md)\n- [Shared file storages](shared_file_storages.md)\n- [Airgapped notebook deployment with Zero Trust Authentication](../deployment/docker.md#deploy-notebooks-as-applications)","ref":"intro_to_teams.html#current-features-in-the-beta"},{"type":"extras","title":"Shared secrets management","doc":"# Shared secrets management","ref":"shared_secrets.html"},{"type":"extras","title":"Overview - Shared secrets management","doc":"This feature allows your team to share Livebook secrets among team members in an easy way.\n\nJust add a secret to your organization hub, and Livebook Teams will synchronize it with the Livebook of every member of your organization.\n\n![](assets/add_shared_secret.png)\n\nYou can also create such secrets directly from a notebook.\n\n![](assets/add_shared_secret_from_notebook.png)\n\nShared secrets updates and deletions will also be synchronized.","ref":"shared_secrets.html#overview"},{"type":"extras","title":"How it works - Shared secrets management","doc":"Here's a video showing how that feature works.","ref":"shared_secrets.html#how-it-works"},{"type":"extras","title":"Security strengths - Shared secrets management","doc":"Livebook Teams cannot access the plain text version of your organization's secrets.\n\nLivebook encrypts your secrets locally in your machine using your Teams key. Then, the secret is sent encrypted to Livebook Teams servers.\n\nWhen a new synchronization is needed, Livebook Teams sends the encrypted secret to the Livebook of team members, and their Livebook decrypts the secret in their local machines using the same Teams key.","ref":"shared_secrets.html#security-strengths"},{"type":"extras","title":"Shared file storages","doc":"# Shared file storages","ref":"shared_file_storages.html"},{"type":"extras","title":"Overview - Shared file storages","doc":"This feature allows your team to share the configuration of S3-compatible storages.\n\nLivebook file storages are used to store notebooks and their files.\n\nWhenever you add (update or detach) a file storage to your organization hub, Livebook Teams will synchronize that with the Livebook of every member of your organization.\n\n![](assets/add_shared_file_storage.png)","ref":"shared_file_storages.html#overview"},{"type":"extras","title":"How it works - Shared file storages","doc":"Here's a video showing how that feature works.","ref":"shared_file_storages.html#how-it-works"},{"type":"extras","title":"Security strengths - Shared file storages","doc":"Livebook Teams cannot access the credentials of your S3 (compatible) account.\n\nLivebook encrypts your S3 credentials locally in your machine using your Teams key. Then, they're sent encrypted to Livebook Teams servers.\n\nWhen a new synchronization is needed, Livebook Teams sends the encrypted credentials to the Livebook of team members, and their Livebook decrypts that in their local machines using the same Teams key.","ref":"shared_file_storages.html#security-strengths"},{"type":"extras","title":"Docker","doc":"# Docker\n\nThere are two main use cases to deploy Livebook in the cloud. The first is to read and write notebooks in the cloud, instead of your machine. The second is to deploy notebooks as applications. This guide covers both as well other details such as clustering.","ref":"docker.html"},{"type":"extras","title":"Livebook in the cloud - Docker","doc":"You can deploy Livebook inside your infrastructure using Docker. The Dockerfile below provides a great starting point:\n\n```dockerfile\nFROM ghcr.io/livebook-dev/livebook\n\n# Configure your port accordingly\nENV LIVEBOOK_PORT 7860\nEXPOSE 7860\n\n# If you have a persistent volume, configure it here\nENV LIVEBOOK_DATA_PATH \"/data\"\nUSER root\nRUN mkdir -p /data\nRUN chmod 777 /data\n```\n\nWe also recommend setting the `LIVEBOOK_PASSWORD` environment variable to a secret value. If it is not set, you will find the token to access Livebook in the logs. See all other supported [environment variables](../../README.md#environment-variables) to learn more.\n\nIf you want to run several Livebook instances behind a load balancer, you need to enable clustering. See the [Clustering](#clustering) section.\n\nIf you plan to limit access to your Livebook via a proxy, we recommend leaving the \"/public\" route of your instances still public. This route is used for integration with the [Livebook Badge](https://livebook.dev/badge/) and other conveniences.\n\n#","ref":"docker.html#livebook-in-the-cloud"},{"type":"extras","title":"Docker compose - Docker","doc":"If using Docker Compose the following template is a good starting point:\n\n```yml\nservices:\n  livebook:\n    image: ghcr.io/livebook-dev/livebook\n    ports:\n      - 8090:8090\n      - 8091:8091\n    environment:\n      - LIVEBOOK_PORT=8090\n      - LIVEBOOK_IFRAME_PORT=8091\n```","ref":"docker.html#docker-compose"},{"type":"extras","title":"Deploy notebooks as applications - Docker","doc":"It is possible to deploy any notebook as an application in Livebook. Inside the notebook, open up the Application pane on the sidebar (with a rocket icon), click \"Deploy with Docker\", and follow the required steps. You will be able to choose a Livebook image, preset clustering options, and more.\n\nIf you are using [Livebook Teams](https://livebook.dev/teams/), you will also have access to airgapped notebook deployment with pre-configured Zero Trust Authentication, shared team secrets and file storages. To get started, open up Livebook, click \"Add Organization\" on the sidebar, and visit the \"Airgapped Deployment\" section of your organization.","ref":"docker.html#deploy-notebooks-as-applications"},{"type":"extras","title":"Clustering - Docker","doc":"If you plan to run several Livebook instances behind a load balancer, you need to enable clustering via the `LIVEBOOK_CLUSTER` environment variable. Currently the only supported value is `dns:QUERY`, in which case nodes ask DNS for A/AAAA records using the given query and try to connect to peer nodes on the discovered IPs.\n\nWhen clustering is enabled, you must additionally set the following env vars:\n\n  * `LIVEBOOK_NODE=livebook_server@IP`, where `IP` is the machine IP of each deployed node\n\n  * You must set `LIVEBOOK_SECRET_KEY_BASE` and `LIVEBOOK_COOKIE` to different random values (use `openssl rand -base64 48` to generate said values)\n\n  * If your cloud requires IPv6, also set `ERL_AFLAGS=\"-proto_dist inet6_tcp\"`\n\n`LIVEBOOK_DISTRIBUTION` is automatically set to `name` if clustering is enabled.\n\nSome variables, like `LIVEBOOK_NODE`, are oftentimes computed at runtime. When using the Livebook Docker image, you can create a file at `/app/user/env.sh` that exports the necessary environment variables. This file is invoked right before booting Livebook.","ref":"docker.html#clustering"},{"type":"extras","title":"Authentication with Cloudflare","doc":"# Authentication with Cloudflare\n\nSetting up Cloudflare authentication will protect all routes of your notebook. It is particularly useful for adding authentication to deployed notebooks. Cloudflare authentication is provided in addition to [Livebook's authentication](../authentication.md) for authoring notebooks.\n\nOnce Cloudflare is enabled, we recommend leaving the \"/public\" route of your instances still public. This route is used for integration with the [Livebook Badge](https://livebook.dev/badge/) and other conveniences.","ref":"cloudflare.html"},{"type":"extras","title":"How to - Authentication with Cloudflare","doc":"To integrate your Cloudflare Zero Trust authentication with Livebook, set the\n`LIVEBOOK_IDENTITY_PROVIDER` environment variable to `cloudflare: `.\n\nFor more details about how to find your `team-name`, see:\nhttps://developers.cloudflare.com/cloudflare-one/glossary/#team-name.\n\nFor more information about Cloudflare Zero Trust, see:\nhttps://developers.cloudflare.com/cloudflare-one/.","ref":"cloudflare.html#how-to"},{"type":"extras","title":"Livebook Teams - Authentication with Cloudflare","doc":"[Livebook Teams](https://livebook.dev/teams/) users have access to airgapped notebook deployment via Docker, with pre-configured Zero Trust Authentication, shared team secrets, and file storages.\n\nFurthermore, if you are deploying multi-session apps via [Livebook Teams](https://livebook.dev/teams/), you can programmatically access data from the authenticated user by calling [`Kino.Hub.app_info/0`](https://hexdocs.pm/kino/Kino.Hub.html#app_info/0).\n\nTo get started, open up Livebook, click \"Add Organization\" on the sidebar, and visit the \"Airgapped Deployment\" section of your organization.","ref":"cloudflare.html#livebook-teams"},{"type":"extras","title":"Authentication with Google IAP","doc":"# Authentication with Google IAP\n\nSetting up Google IAP authentication will protect all routes of your notebook. It is particularly useful for adding authentication to deployed notebooks. Google IAP authentication is provided in addition to [Livebook's authentication](../authentication.md) for authoring notebooks.\n\nOnce Google IAP is enabled, we recommend leaving the \"/public\" route of your instances still public. This route is used for integration with the [Livebook Badge](https://livebook.dev/badge/) and other conveniences.","ref":"google_iap.html"},{"type":"extras","title":"How to - Authentication with Google IAP","doc":"To integrate your Google Identity-Aware Proxy (IAP) authentication with Livebook,\nset the `LIVEBOOK_IDENTITY_PROVIDER` environment variable to `google_iap: `.\n\nFor more information about Google IAP, see https://cloud.google.com/iap/docs/concepts-overview.\n\nOnly access with Google accounts is supported. See https://cloud.google.com/iap/docs/authenticate-users-google-accounts.\n\nFor more details about how to find your JWT audience, see https://cloud.google.com/iap/docs/signed-headers-howto and look for \"Signed Header JWT Audience.\"","ref":"google_iap.html#how-to"},{"type":"extras","title":"Livebook Teams - Authentication with Google IAP","doc":"[Livebook Teams](https://livebook.dev/teams/) users have access to airgapped notebook deployment via Docker, with pre-configured Zero Trust Authentication, shared team secrets, and file storages.\n\nFurthermore, if you are deploying multi-session apps via [Livebook Teams](https://livebook.dev/teams/), you can programmatically access data from the authenticated user by calling [`Kino.Hub.app_info/0`](https://hexdocs.pm/kino/Kino.Hub.html#app_info/0).\n\nTo get started, open up Livebook, click \"Add Organization\" on the sidebar, and visit the \"Airgapped Deployment\" section of your organization.","ref":"google_iap.html#livebook-teams"},{"type":"extras","title":"Authentication with Tailscale","doc":"# Authentication with Tailscale\n\nSetting up Tailscale authentication will protect all routes of your notebook. It is particularly useful for adding authentication to deployed notebooks. Tailscale authentication is provided in addition to [Livebook's authentication](../authentication.md) for authoring notebooks.\n\nOnce Tailscale is enabled, we recommend leaving the \"/public\" route of your instances still public. This route is used for integration with the [Livebook Badge](https://livebook.dev/badge/) and other conveniences.","ref":"tailscale.html"},{"type":"extras","title":"How to - Authentication with Tailscale","doc":"To integrate Tailscale authentication with Livebook,\nset the `LIVEBOOK_IDENTITY_PROVIDER` environment variable to `tailscale:tailscale-socket-path`, make sure the `tailscale` CLI is installed and available on your machine (or your Docker image).\n\nIf you want to access Livebook on the same machine as you are hosting it,\nyou must also set the `LIVEBOOK_IP` variable to your Tailscale IP.\n\nTo do both of these things, run:\n\n```bash\nLIVEBOOK_IP=$(tailscale ip -1 | tr -d '\\n') \\\nLIVEBOOK_IDENTITY_PROVIDER=tailscale:/var/run/tailscale/tailscaled.sock \\\nlivebook server\n```\n\nSee https://tailscale.com/blog/tailscale-auth-nginx/ for more information\non how Tailscale authentication works.\n\n#","ref":"tailscale.html#how-to"},{"type":"extras","title":"macOS - Authentication with Tailscale","doc":"On macOS, when Tailscale is installed via the Mac App Store, no unix socket is exposed.\nInstead, a TCP port is made available and protected via a password, which needs to be located.\nTailscale itself uses lsof for this. This method is replicated in the bash script below,\nwhich will start Livebook with your Tailscale IP and correct port and password.\n\n```bash\n#!/bin/bash\naddr_info=$(lsof -n -a -c IPNExtension -F | sed -n 's/.*sameuserproof-\\([[:digit:]]*-.*\\).*/\\1/p')\nport=$(echo \"$addr_info\" | cut -d '-' -f 1)\npass=$(echo \"$addr_info\" | cut -d '-' -f 2)\nLIVEBOOK_IP=$(exec $(ps -xo comm | grep MacOS/Tailscale$) ip | head -1 | tr -d '\\n') \\\nLIVEBOOK_IDENTITY_PROVIDER=tailscale:http://:$pass@127.0.0.1:$port \\\nlivebook server\n```","ref":"tailscale.html#macos"},{"type":"extras","title":"Livebook Teams - Authentication with Tailscale","doc":"[Livebook Teams](https://livebook.dev/teams/) users have access to airgapped notebook deployment via Docker, with pre-configured Zero Trust Authentication, shared team secrets, and file storages.\n\nFurthermore, if you are deploying multi-session apps via [Livebook Teams](https://livebook.dev/teams/), you can programmatically access data from the authenticated user by calling [`Kino.Hub.app_info/0`](https://hexdocs.pm/kino/Kino.Hub.html#app_info/0).\n\nTo get started, open up Livebook, click \"Add Organization\" on the sidebar, and visit the \"Airgapped Deployment\" section of your organization.","ref":"tailscale.html#livebook-teams"}],"content_type":"text/markdown"}